# naxalnet

**naxalnet** is an experiment to create a wireless mesh network for
communicating with each other during an internet shutdown, using
existing software and tech as much as possible. Currently
you can only communicate with other peers running naxalnet or
using the same network as naxalnet. It uses
[B.A.T.M.A.N. Advanced][batman-adv],
an implementation of the B.A.T.M.A.N. routing protocol to
communicate with peers.

The name naxal comes from Naxalbari, a village in Darjeeling,
West Bengal.

<!-- UNCOMMENT WHEN NECESSARY

**Disclaimer**:
In case you are either 1) a complete idiot; or 2) a member of the saffron
brigade; or 3) both, please be aware that this project is not affiliated
with any groups designated as "terrorist" groups in India.

Using the name Naxal does not imply any form of connection
with anyone the government of India collectively calles Urban
Naxals (human rights activists, lawyers, poets, writers, journalists
or anyone else advocating for their rights).

-->

## Requirements

- systemd{,-networkd} v248 or more (for [batman support][batman-systemd])
- Linux kernel with batman-adv module (if `modinfo batman-adv` shows
  no error then you already have it)
- iwd (for starting ad-hoc network)
- python3
- python-setuptools (for building)
- [python-dasbus][]
- wifi adapter with ad-hoc support
- two or more computers with wifi adapter, called nodes
- systemd-resolved (optional, for DNS)
- batctl (optional, for debugging)

## Installing

### Arch Linux

Install [naxalnet][aur] (or [naxalnet-git][aur-devel] for the
development version) from the AUR with your favourite helper:

```sh
yay -S naxalnet
```

Optionally, [setup systemd-resolved][arch-resolved] for DNS if any
of the nodes have internet access.

### Manually

Clone the repo and cd into it.

```sh
git clone https://git.disroot.org/pranav/naxalnet.git
cd naxalnet
```

Or, if you have an [IPFS client][ipfs] running, try:

```sh
git clone http://k51qzi5uqu5dlye74be0n9iihwk6sm54vexo7bf7pdr4w811y6mmrcp25djozv.ipns.localhost:8080/naxalnet.git
```

Run `sudo make install` to install naxalnet. This will install naxalnet in
`/usr/bin/naxalnet`.

After installing, reload systemd so that you can enable `naxalnet.service`
without rebooting:

```sh
sudo systemctl daemon-reload
```

## How to use

You need more than one computer running for the connection to work.

### Communicate between peers

Connect a wifi adapter to all the computers you intend to run
naxalnet.
Start the naxalnet service on all of them:

```sh
sudo systemctl start naxalnet.service
```

To test if it works, run `ip addr` to find out your address.
Note the `inet` or `inet6` address of `bridge0`. Ping the address
from another computer (example: `ping 169.254.62.90`) to find out
if it is online. Press Ctrl-C to stop.

### Getting internet access

Connect an ethernet to any of the peers and start naxalnet.
Now all the peers should be able to connect after renewing
their DHCP connection (`sudo networkctl renew bridge0`).

### Tethering via WiFi AP

Connect two wifi adapters on a device and start naxalnet.
Now an ap will be created on one of the adapters with
SSID `NaxalNet` and password `naxalnet256`.
If you had set up internet access on one of the peers, internet
can be accessed from the AP.

### Running at boot

Starting the service will stop `NetworkManager.service` and
`wpa_supplicant.service` if it is running. If you start either of these
services after naxalnet is started, systemd will stop naxalnet.

To run naxalnet at boot, enable the service:

```sh
sudo systemctl enable naxalnet.service
```

Now naxalnet will configure a batman interface on every boot.
Disable the service to stop running at boot:

```sh
sudo systemctl disable naxalnet.service
```

### Stopping the service

```sh
# Stop the services
sudo systemctl stop naxalnet systemd-networkd systemd-resolved iwd
# Delete the virtual interfaces created by naxalnet
sudo networkctl delete bat0 bridge0
```

If your distribution uses NetworkManager, starting `naxalnet.service`
will have stopped it. Start NetworkManager again:

```sh
sudo systemctl start NetworkManager.service
```

## How it works

The program naxalnet copies some `systemd-networkd` configuration files
into networkd's runtime configuration directory. It uses iwd to start
an ad-hoc network named "HelloWorld". See the
[systemd-networkd](systemd-networkd) directory
to see how systemd-networkd configures the network. You can use
services like [IPFS][], [Jami][], [Secure Scuttlebutt][ssb]
and others which can work on an intranet.

## Uninstalling

If you installed naxalnet manually, there is no way to uninstall
than manually removing the files:

```sh
sudo pip uninstall naxalnet
sudo rm -rf /usr/share/naxalnet* /usr/lib/systemd/system/naxalnet.service
```

## Contributing

See [HACKING.md](HACKING.md)

## Similar projects

The following projects are similar to naxalnet, but are not designed
to be used in a laptop or computer with wifi adapter. If you live in
an area where the materials required for any of them are easily
available, consider using them instead of naxalnet.

- [LibreMesh][libremesh]: framework for OpenWrt-based
  firmwares
- [disaster.radio][]: solar-powered communications network

## License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

See [LICENSE](LICENSE) for the complete version of the
license.

[batman-adv]: https://www.open-mesh.org/projects/batman-adv/wiki
[ipfs]: https://ipfs.io
[jami]: https://jami.net
[ssb]: https://scuttlebutt.nz
[python-dasbus]: https://github.com/rhinstaller/dasbus
[aur]: https://aur.archlinux.org/packages/naxalnet
[aur-devel]: https://aur.archlinux.org/packages/naxalnet-git
[arch-resolved]: https://wiki.archlinux.org/title/Systemd-resolved#DNS
[batman-systemd]: https://www.open-mesh.org/news/101
[libremesh]: https://libremesh.org
[disaster.radio]: https://disaster.radio/
